@@ -7,8 +7,8 @@ from hcli.utils.permanent_storage import read_field, set_field
 
 app = typer.Typer()
 
-token = read_field('token')
-organization_id = read_field('organization_id')
+token = read_field("token")
+organization_id = read_field("organization_id")
 
 core_api = ApiClient(
     "https://api.huddu.io", headers={"Authorization": f"Token {token}"}
@@ -24,24 +24,25 @@ def list():
     table.add_column("Organization ID")
 
     for i in organizations.get("data"):
-        table.add_row(
-            i.get("name"),
-            i.get("id")
-        )
+        table.add_row(i.get("name"), i.get("id"))
 
     print(table)
 
 
 @app.command()
 def set(organization_name: str):
-    organizations = core_api.request("GET", f"/search?resources=organizations&q=name:{organization_name}")
+    organizations = core_api.request(
+        "GET", f"/search?resources=organizations&q=name:{organization_name}"
+    )
     if len(organizations.get("data")) == 0:
         print(f"[red]no organization for name {organization_name} found")
     else:
         organization = organizations["data"][0]
         set_field("organization_id", organization["id"])
 
-        print(f"[green]successfully set organization to [bold]{organization_name}[/bold]")
+        print(
+            f"[green]successfully set organization to [bold]{organization_name}[/bold]"
+        )
 
 
 @app.command()
@@ -50,4 +51,6 @@ def get():
         organization = core_api.request("GET", f"/organizations/{organization_id}")
         print(organization)
     else:
-        print("[red]No organization set. You can do so via [bold]hcli organizations set[/bold]")
+        print(
+            "[red]No organization set. You can do so via [bold]hcli organizations set[/bold]"
+        )
